extract_module_reference_extended

Function extract_module_reference_extended 

pub fn extract_module_reference_extended(
    text: &str,
    cursor_pos: usize,
) -> Option<String>
Extract a module reference at cursor_pos as a canonical module name, including use parent/use base argument modules.

This is the extended version that also resolves quoted module names inside use parent 'Module::Name' and use base qw(Module::Name).